[MOBY-guts] biomoby commit

Gary Schiltz gss at pub.open-bio.org
Thu Oct 27 22:22:09 UTC 2005


gss
Thu Oct 27 18:22:09 EDT 2005
Update of /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet
In directory pub.open-bio.org:/tmp/cvs-serv10259/src/org/semanticmoby/servlet

Modified Files:
	AbstractMobyServlet.java package.html 
Log Message:
Refer to Resource rather than Service

s-moby/ref-impl/core/src/org/semanticmoby/servlet AbstractMobyServlet.java,1.3,1.4 package.html,1.1,1.2
===================================================================
RCS file: /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet/AbstractMobyServlet.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.1 -r1.2
--- /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet/package.html	2004/11/23 00:18:46	1.1
+++ /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet/package.html	2005/10/27 22:22:09	1.2
@@ -1,5 +1,5 @@
 <html>
 <body>
-Classes to facilitate building Semantic MOBY services using Java servlets.
+Classes to facilitate building Semantic MOBY resources using Java servlets.
 </body>
-</html>
\ No newline at end of file
+</html>




More information about the MOBY-guts mailing list
diff -u -r1.3 -r1.4
--- /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet/AbstractMobyServlet.java	2005/10/09 01:33:06	1.3
+++ /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet/AbstractMobyServlet.java	2005/10/27 22:22:09	1.4
@@ -67,7 +67,7 @@
      * in, that serves as "input" to the provider.
      * @return a graph containing the work product of the provider.
      */
-    protected abstract void handleRequest(MOBYService requestGraph);
+    protected abstract void handleRequest(MOBYResource requestGraph);
 
 
     /**
@@ -110,7 +110,7 @@
 
 
     /**
      * By MOBY convention, an HTTP POST equates to a request for the service
      * provided by a provider.
      */
     public void doPost(HttpServletRequest request, HttpServletResponse response)
@@ -127,16 +127,16 @@
                 ParamReader.getParameter(MOBY.GRAPH_PARAMETER_NAME, request);
             Parser      parser =
                 Parser.forString(graphString, Parser.LANGUAGE_RDF_XML);
-            MOBYService service = parser.parseService();
+            MOBYResource resource = parser.parseResource();
 
             // Invoke the abstract handleRequest() method in order for the
             // provider servlet to do whatever it does to the graph.
             //
-            handleRequest(service);
+            handleRequest(resource);
 
             // Send the graph back in response
             //
-            service.serialize(out);
+            resource.serialize(out);
         } catch (Throwable t) {
 
             t.printStackTrace();
@@ -110,7 +110,7 @@
 
     /**
-     * By MOBY convention, an HTTP POST equates to a request for the service
+     * By MOBY convention, an HTTP POST equates to a request for the resource
      * provided by a provider.
      */

===================================================================
RCS file: /home/repository/moby/s-moby/ref-impl/core/src/org/semanticmoby/servlet/package.html,v
retrieving revision 1.1
retrieving revision 1.2